Changelog
=========


2016-09-18a : v0.7.4 'pandas walk'
-------------------------------------------

* bug fix: pandas 0.19 compatibility fix

older versions :
----------------

 * 0.7.3 : Python keyword is 'pass', not 'Pass'
 * 0.7.2 : support space in dataframe column title
 * 0.7.1 : cleanups
 * 0.7.0 : support of pandas 0.14 sqlalchemy
 * 0.6.6 : sqlite_py_manager.py browser added functions and fix, fix tokenizer error in baresql
 * 0.6.4 : minimal compatibility of sqlite_py_manager.py with old versions : python 2.7 and sqlite 3.6.21
 * 0.6.1 : a pure standard-installation Python SQLite browser in examples\sqlite_py_manager.py 
 * 0.6 : first version with correct mysql support
 * 0.5.1 : bug correction + SQLite3.8.3 beta from 2013-01-22
 * 0.5 : use SQLite true CTE if SQLite >= 3.8.3
 * 0.4.1 : inline CTE when syntax is "with x as (y)"
 * 0.4 : rewrite with token
 * 0.3.2 : support comments in the SQL
 * 0.3 : includes a basic CTE
 * 0.2 : add "range(10)" iterable object support 
 * 0.1 : initial version
